summaryrefslogtreecommitdiff
path: root/plugins/new_user_identity/new_user_identity.php
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/new_user_identity/new_user_identity.php')
-rw-r--r--plugins/new_user_identity/new_user_identity.php11
1 files changed, 6 insertions, 5 deletions
diff --git a/plugins/new_user_identity/new_user_identity.php b/plugins/new_user_identity/new_user_identity.php
index 3943134b2..200d9accd 100644
--- a/plugins/new_user_identity/new_user_identity.php
+++ b/plugins/new_user_identity/new_user_identity.php
@@ -8,18 +8,17 @@
*
* @version @package_version@
* @author Kris Steinhoff
- * @license GNU GPLv3+
*
* Example configuration:
*
* // The id of the address book to use to automatically set a new
* // user's full name in their new identity. (This should be an
* // string, which refers to the $config['ldap_public'] array.)
* $config['new_user_identity_addressbook'] = 'People';
*
* // When automatically setting a new users's full name in their
* // new identity, match the user's login name against this field.
- * $config['new_user_identity_match'] = 'uid';
+ * $rcmail_config['new_user_identity_match'] = 'uid';
*/
class new_user_identity extends rcube_plugin
{
@@ -34,6 +33,8 @@ class new_user_identity extends rcube_plugin
function lookup_user_name($args)
{
+ $rcmail = rcmail::get_instance();
+
if ($this->init_ldap($args['host'])) {
$results = $this->ldap->search('*', $args['user'], true);
if (count($results->records) == 1) {
@@ -42,7 +43,7 @@ class new_user_identity extends rcube_plugin
$args['user_name'] = $user_name;
if (!$args['user_email'] && strpos($user_email, '@')) {
- $args['user_email'] = rcube_utils::idn_to_ascii($user_email);
+ $args['user_email'] = rcube_idn_to_ascii($user_email);
}
}
}
@@ -8,18 +8,17 @@
* // The id of the address book to use to automatically set a new
* // user's full name in their new identity. (This should be an
- * // string, which refers to the $config['ldap_public'] array.)
- * $config['new_user_identity_addressbook'] = 'People';
+ * // string, which refers to the $rcmail_config['ldap_public'] array.)
+ * $rcmail_config['new_user_identity_addressbook'] = 'People';
*
* // When automatically setting a new users's full name in their